@@ -6,15 +6,19 @@ use PDF::Builder;
 #use Data::Dumper; # for debugging
 # $Data::Dumper::Sortkeys = 1; # hash keys in sorted order
 
-our $VERSION = '3.026'; # VERSION
-our $LAST_UPDATE = '3.026'; # manually update whenever code is changed
+our $VERSION = '3.027'; # VERSION
+our $LAST_UPDATE = '3.027'; # manually update whenever code is changed
 
+# README.md is used below on page 5. Be sure to insert a fresh copy at build 
+#  time, and check if goes more pages. \ -> \\, $PERL_version -> \$PERL_version
 my $use_Table = 1; # if 1, use PDF::Table for table example
 # TBD automatically check if PDF::Table available, and if so, use it
 
-my $pdf = PDF::Builder->new();
+#my $pdf = PDF::Builder->new();
+my $pdf = PDF::Builder->new('compress'=>'none');
 my $content;
 my ($page, $text, $grfx);
+my $page_num = 0;
 
 my $name = $0;
 $name =~ s/\.pl/.pdf/; # write in examples directory
@@ -22,11 +26,16 @@ $name =~ s/\.pl/.pdf/; # write in examples directory
 my $magenta = '#ff00ff';
 my $fs = 15;
 my ($rc, $next_y, $unused);
+print "CAUTION: page 4 requires that your HTML::Tagset installation be patched\n  so that <ins> and <del> are handled properly!\n";
+# for debugging use
+if (0) { #############################################
+} #############################################
 
 print "======================================================= pg 1\n";
 $page = $pdf->page();
-$text = $page->text();
 $grfx = $page->gfx();
+$text = $page->text();
+footer(++$page_num, $pdf, $text);
 
 print "---- single string entries\n";
 $text->column($page, $text, $grfx, 'none', 
@@ -87,8 +96,9 @@ $text->column($page, $text, $grfx, 'pre', [
 # larger font size and narrower columns to force line wraps
 print "======================================================= pg 2\n";
 $page = $pdf->page();
-$text = $page->text();
 $grfx = $page->gfx();
+$text = $page->text();
+footer(++$page_num, $pdf, $text);
 
 print "---- single string entries\n";
  
@@ -158,8 +168,9 @@ print "======================================================= pg 3\n";
 #
 # Lorem Ipsum text ('none') in mix of single string and array
 $page = $pdf->page();
-$text = $page->text();
 $grfx = $page->gfx();
+$text = $page->text();
+footer(++$page_num, $pdf, $text);
 
 # as an array of strings
 my @ALoremIpsum = (
@@ -203,15 +214,19 @@ consequatur aut perferendis doloribus asperiores repellat.
 my $SLoremIpsum = join("\n",@ALoremIpsum);
 
 print "---- Lorem Ipsum array of string entries, default paragraphs\n";
+$text->column($page, $text, undef, 'html', 
+  "<h2>Paragraphs with default characteristics</h2>", 'rect'=>[50,730, 500,25]);
 # default paragraph indent and top margin
 restore_props($text, $grfx);
 ($rc, $next_y, $unused) =
     $text->column($page, $text, $grfx, 'none', \@ALoremIpsum, 
-	          'rect'=>[50,750, 500,300], 'outline'=>$magenta );
+	          'rect'=>[50,700, 500,250], 'outline'=>$magenta );
 if ($rc) { 
     print STDERR "Lorem Ipsum array overflowed the column!\n";
 }
 print "---- Lorem Ipsum string entry, block-style paragraphs\n";
+$text->column($page, $text, undef, 'html', 
+  "<h2>Paragraphs with block style (no indent, vertical space)</h2>", 'rect'=>[50,380, 500,25]);
 # no indent, extra top margin
 restore_props($text, $grfx);
 ($rc, $next_y, $unused) =
@@ -226,8 +241,9 @@ if ($rc) {
 print "======================================================= pg 4\n";
 print "---- Customer sample Markdown and Table\n";
 $page = $pdf->page();
-$text = $page->text();
 $grfx = $page->gfx();
+$text = $page->text();
+footer(++$page_num, $pdf, $text);
 
 $content = <<"END_OF_CONTENT";
 Example of Markdown that needs to be supported in document text blocks. There is no need to support this within tables, although it would be a "nice" feature.
@@ -436,31 +452,46 @@ if ($use_Table) {
 }
 
 # more pages with more extensive MD
-print "======================================================= pg 5-8\n";
+print "======================================================= pg 5-10\n";
 print "---- A README.md file for PDF::Builder\n";
 $page = $pdf->page();
-$text = $page->text();
 $grfx = $page->gfx();
-#  might need two or even three pages
+$text = $page->text();
+footer(++$page_num, $pdf, $text);
+#  might need three or four pages
+#  three <img> calls (GitHub buttons), several `code` 
+#  escape $ and \ in several lines, unescape \* 
+#  example block in Paper Sizes note needs manual reformat (revisit
+#    when <pre> supported)
 $content = <<"END_OF_CONTENT";
-# PDF::Builder
+# PDF::Builder release 3.027
 
-A Perl library to facilitate the creation and modification of PDF files
+A Perl library to create and modify PDF (Portable Document Format) files
 
 ## What is it?
 
-PDF::Builder is a **fork** of the popular PDF::API2 Perl library. It provides a 
-library of modules and functions so that a PDF file (document) may be built and 
-maintained from Perl programs. It is not a WYSIWYG editor; nor is it a canned 
-utility or converter. It does _not_ have a GUI -- it is driven by your Perl 
-program. It is a set of **building blocks** with which you can perform a wide 
-variety of operations, ranging from basic operations such as selecting a font 
-face, to defining an entire page at a time in the document, using a large 
-subset of either Markdown or HTML markup languages. You can call it from 
-arbitrary Perl programs, which may even create content on-the-fly (or read it 
-in from other sources). Quite a few code examples are provided, to help you to 
-get started with the process of creating a PDF document. Many enhancements are 
-in the pipeline to make PDF::Builder even more powerful and versatile.
+PDF::Builder is a **fork** of the popular PDF::API2\* Perl library. It
+provides a library of modules and functions so that a PDF file (document) may
+be built and maintained from Perl programs (it can also read in, modify, and
+write back out existing PDF files). It is not a WYSIWYG editor; nor is it a
+canned utility or converter. It does _not_ have a GUI or command line interface
+-- it is driven by _your_ Perl program. It is a set of **building blocks**
+(methods) with which you can perform a wide variety of operations, ranging
+from basic operations (such as selecting a font face), to defining an entire
+page at a time in the document (using a large subset of either Markdown or HTML
+markup languages). You can call it from arbitrary Perl programs, which may even
+create content on-the-fly (or read it in from other sources). Quite a few code
+examples are provided, to help you to get started with the process of creating
+a PDF document. Many enhancements are in the pipeline to make PDF::Builder even
+more powerful and versatile.
+
+\\*Note that PDF::Builder is **not** built on PDF::API2, and does **not**
+require that it be installed. The two libraries are completely independent of
+each other and one will not interfere with the other if both are installed.
+
+**Gadzooks!** For a delightful look at the (rather grisly) origin of this
+typographical term, as well as many other terms, watch
+https://www.youtube.com/watch?v=cd5iFbuNKv8 .
 
 [Home Page](https://www.catskilltech.com/FreeSW/product/PDF%2DBuilder/title/PDF%3A%3ABuilder/freeSW_full), including Documentation and Examples.
 
@@ -469,16 +500,17 @@ in the pipeline to make PDF::Builder even more powerful and versatile.
 [![Maintenance](https://img.shields.io/badge/Maintained%3F-yes-green.svg)](https://GitHub.com/PhilterPaper/Perl-PDF-Builder/graphs/commit-activity)
 
 This archive contains the distribution PDF::Builder.
-See **Changes** file for the version.
+See **Changes** file for the version and list of changes from the previous
+release.
 
-## Obtaining the Package
+## Obtaining and Installing the Package
 
 The installable Perl package may be obtained from
 "https://metacpan.org/pod/PDF::Builder", or via a CPAN installer package. If
 you install this product, only the run-time modules will be installed. Download
-the full `.tar.gz` file and unpack it (hint: on Windows,
-**7-Zip File Manager** is an excellent tool) to get utilities, test buckets,
-example usage, etc.
+the full `.tar.gz` file and unpack it (uncompress, then extract directory --
+hint: on Windows, **7-Zip File Manager** is an excellent tool) to get
+utilities, test buckets, example usage, etc.
 
 Alternatively, you can obtain the full source files from
 "https://github.com/PhilterPaper/Perl-PDF-Builder", where the ticket list
@@ -486,32 +518,55 @@ Alternatively, you can obtain the full source files from
 version, this will have to be manually installed (copy files; there are no XS
 compiles at this time).
 
+Other than an installer for standard CPAN packages (such as 'cpan' on
+Strawberry Perl for Windows), no other tools or manually-installed prereqs are
+needed (worst case, you can unpack the `.tar.gz` file and copy files into
+place yourself!). Currently there are no compiles and links (Perl extensions)
+done during the install process, only copying of .pm Perl module files. 
+
+A package installer such as "cpan" (included with Strawberry Perl and some
+other systems) can retrieve the package, unpack and copy files, and run 
+installation tests without manual intervention. Not only PDF::Builder itself, 
+but any needed prerequisites, may be quickly installed in this manner. Some 
+Perl distributions (e.g., ActiveState) may repackage PDF::Builder and 
+prerequisites into their own install format, as may Linux distributions such
+as Red Hat or SUSE. Finally, it is possible to copy files directly from the 
+GitHub repository to your system, and manually run the "t" (installation) 
+tests, all without going through a `.tar.gz` CPAN package. There are many 
+possibilities.
+
 Note that there are several "optional" libraries (Perl modules) used to extend
 and improve PDF::Builder. Read about the list of optional libraries in
 PDF::Builder::Docs, and decide whether or not you want to install any of them.
-By default, none are installed.
+By default, **none** are installed.
 
 ## Requirements
 
 ### Perl
 
-**Perl 5.26** or higher. It will likely run on somewhat earlier versions, but
+**Perl 5.28** or higher. It will likely run on somewhat earlier versions, but
 the CPAN installer may refuse to install it. The reason this version was
 chosen was so that LTS (Long Term Support) versions of Perl going back about
 6 years are officially supported (by PDF::Builder), and older versions are not
 supported. The intent is to not waste time and effort trying to fix bugs which
 are an artifact of old Perl releases.
 
+Usually about once a year the minimum level is bumped up, but this depends on 
+whether Strawberry releases the newest Perl level. As Strawberry Perl releases 
+new Perl levels, usually on an annual basis, we intend to bump up our required 
+minimum Perl level (even-numbered production releases), to keep support for the 
+last 6 calendar years of Perl releases, dropping older ones.
+
 #### Older Perls
 
-If you MUST install on an older (pre 5.26) Perl, you can try the following for
+If you MUST install on an older (pre 5.28) Perl, you can try the following for
 Strawberry Perl (Windows). NO PROMISES! Something similar MAY work for other
 OS's and Perl installations:
 
 1. Unpack installation file (`.tar.gz`, via a utility such as 7-Zip) into a directory, and cd to that directory
-1. Edit META.json and change 5.026000 to 5.016000 or whatever level desired
-1. Edit META.yml and change 5.026000 to 5.016000 or whatever level desired
-1. Edit Makefile.PL and change `use 5.026000;` to `use 5.016000;`, change `\$PERL_version` from `5.026000` to `5.016000`
+1. Edit META.json and change 5.028000 to 5.016000 or whatever level desired
+1. Edit META.yml and change 5.028000 to 5.016000 or whatever level desired
+1. Edit Makefile.PL and change `use 5.028000;` to `use 5.016000;`, change `\$PERL_version` from `5.028000` to `5.016000`
 1. `cpan .`
 
 Note that some Perl installers MAY have a means to override or suppress the
@@ -521,8 +576,8 @@ edited directory back into a `.tar.gz` installable. YMMV.
 If all goes well, PDF::Builder will be installed on your system. Whether or
 not it will RUN is another matter. Please do NOT open a bug report (ticket)
 unless you're absolutely sure that the problem is not a result of using an old
-Perl release, e.g., PDF::Builder is using a feature introduced in Perl 5.018
-and you're trying to run Perl 5.002!
+Perl release, e.g., PDF::Builder is using a feature introduced in Perl 5.022
+and you're trying to run Perl 5.012!
 
 ### Libraries used
 
@@ -541,9 +596,9 @@ These libraries should be automatically installed...
 
 These libraries are _recommended_ for improved functionality and performance.
 The default behavior is **not** to attempt to install them during PDF::Builder
-installation, in order to speed up the testing process and not clutter up 
-matters, especially if an optional package fails to install. You can always 
-manually install them later, if you desire to make use of their added 
+installation, in order to speed up the testing process and not clutter up
+matters, especially if an optional package fails to install. You can always
+manually install them later, if you desire to make use of their added
 functionality.
 
 * Perl::Critic (1.150 or higher, need if running tools/1\_pc.pl)
@@ -552,23 +607,40 @@ functionality.
 * HarfBuzz::Shaper (0.024 or higher, needed for Latin script ligatures and kerning, as well as for any complex script such as Arabic, Indic scripts, or Khmer)
 * Text::Markdown (1.000031 or higher, needed if using 'md1' markup)
 * HTML::TreeBuilder (5.07 or higher, needed if using 'html' or 'md1' markup)
-* Pod::Simple::XHTML (3.45 or higher, needed if using buildDoc utility to create HTML documentation)
+* Pod::Simple::XHTML (3.45 or higher, needed if using buildDoc.pl utility to create HTML documentation)
+* SVGPDF (0.087 or higher, needed if using SVG image functions)
 
-If an optional package is needed, but not installed, sometimes PDF::Builder
-will be able to fall back to built-in partial functionality (TIFF and PNG 
-images), but other times will fail. After installing the missing package, you 
-may wish to then run the t-test suite for that library to confirm that it is 
+If an optional package is needed for certain extended functionality, but not
+installed, sometimes PDF::Builder
+will be able to fall back to built-in partial functionality (TIFF and PNG
+images), but other times will fail. After installing the missing package, you
+may wish to then run the t-test suite for that library to confirm that it is
 properly running, as well as running the examples.
 
-Other than an installer for standard CPAN packages (such as 'cpan' on
-Strawberry Perl for Windows), no other tools or manually-installed prereqs are
-needed (worst case, you can unpack the `.tar.gz` file and copy files into
-place yourself!). Currently there are no compiles and links (Perl extensions)
-done during the install process, only copying of .pm Perl module files.
+**Note** that some of these packages, in turn, make use of various open source
+libraries (DLLs/shared libs) that you may need to hunt around for, and install
+on your system before you can install a given package. That is, they may not
+necessarily come with your Operating System or Perl installation. Some such
+packages may try to use "Alien" to build such prereqs, if missing. Other
+packages are "pure Perl" and should install without trouble.
+
+#### Fixes needed to OPTIONAL packages
+
+Sometimes fixes or patches are needed for optional prerequisites. See the file
+**INFO/Prereq\_fixes.md** for a list of known issues.
+
+### External utilities
+
+t/tiff.t (install testing for TIFF support) makes use of GhostScript and 
+ImageMagick (convert utility). You may need to install these in order to get
+full testing (tests that need them will be skipped if they are not installed).
+Note that it has been reported that some versions of Mac Perl systems have
+a 'convert' utility that is missing the default Arial font, and thus will fail
+(see ticket 223).
 
 ## Manually building
 
-As is the usual practice with building such a package (from the command line), 
+As is the usual practice with building such a package (from the command line),
 the steps are:
 
 1. perl Makefile.PL
@@ -576,27 +648,29 @@ the steps are:
 1. make test
 1. make install
 
-If you have your system configured to run Perl for a .pl/.PL file, you may be 
-able to omit "perl" from the first command, which creates a Makefile. "make" 
-is the generic command to run (it feeds on the Makefile), but your system may 
-have it under a different name, such as dmake (Strawberry Perl on Windows), 
-gmake, or nmake.
+If you have your system configured to run Perl for a .pl/.PL file, you may be
+able to omit "perl" from the first command, which creates a Makefile. "make"
+is the generic command to run (it feeds on the Makefile produced by
+Makefile.PL), but your system may have it under a different name, such as
+dmake, gmake (e.g., Strawberry Perl on Windows), or nmake.
 
-PDF::Builder does not currently compile and link anything, so gcc, g++, etc.
-will not be used. The build process merely copies .pm files around, and
-runs the "t" tests to confirm the proper installation.
+PDF::Builder does not currently compile and link anything, so `gcc`, `g++`,
+etc. will not be used. The build process merely copies .pm files into place,
+and runs the "t" tests to confirm the proper installation.
 
 ## Copyright
 
-This software is Copyright (c) 2017-2023 by Phil M. Perry.
+This software is Copyright (c) 2017-2025 by Phil M. Perry.
 
-Previous copyrights are held by others (Steve Simms, Alfred Reibenschuh, et al.). See The HISTORY section of the documentation for more information.
+Previous copyrights are held by others (Steve Simms, Alfred Reibenschuh, 
+et al.). See The HISTORY section of the documentation for more information.
 
 We would like to acknowledge the efforts and contributions of a number of
 users of PDF::Builder (and its predecessor, PDF::API2), who have given their
 time to report issues, ask for new features, and have even contributed code.
 Generally, you will find their names listed in the Changes and/or issue tickets
-related to some particular item.
+related to some particular item. See the **INFO/ACKNOWLEDGE.md** and
+**INFO/SPONSORS** files.
 
 ## License
 
@@ -620,17 +694,18 @@ Art progresses! Just please be considerate and acknowledge the work of others
 that you are building on, as well as pointing back to this package. Drop us a
 note with news of your project (if based on the code and algorithms in
 PDF::Builder, or even just heavily inspired by it) and we'll be happy to make
-a pointer to your work. The more cross-pollination, the better!
+a pointer to _your_ work. The more cross-pollination, the better!
 
 ## See Also
 
+* INFO/SUPPORT file for information on reporting bugs, etc. via GitHub Issues
+* INFO/DEPRECATED file for information on deprecated features
+* INFO/KNOWN\_INCOMP file for known incompatibilities with PDF::API2
+* INFO/Prereq\_fixes.md possible patches for prerequisites
 * CONTRIBUTING file for how to contribute to the project
 * LICENSE file for more on the license term
 * INFO/RoadMap file for the PDF::Builder road map
 * INFO/ACKNOWLEDGE.md for "thank yous" to those who contributed to this product
-* INFO/SUPPORT file for information on reporting bugs, etc. via GitHub Issues 
-* INFO/DEPRECATED file for information on deprecated features
-* INFO/KNOWN\_INCOMP file for known incompatibilities with PDF::API2
 * INFO/CONVERSION file for how to convert from PDF::API2 to PDF::Builder
 * INFO/Changes\* files for older change logs
 * INFO/PATENTS file for information on patents
@@ -644,7 +719,7 @@ and go to the `docs/` directory. Run `buildDoc.pl --all` to generate the full
 tree of documentation. There's a lot of additional information in the
 PDF::Builder::Docs module (it's all documentation).
 
-You may find it more convenient to point your browser to our 
+You may find it more convenient to point your browser to our
 [Home Page](https://www.catskilltech.com/FreeSW/product/PDF-Builder/title/PDF%3A%3ABuilder/freeSW_full)
 to see the full documentation build (as well as most of the example outputs).
 
@@ -653,215 +728,73 @@ We hope to more fully address this in the future, but for now, get the full
 installation and look at the `examples/` and `contrib/` directories for sample
 code that may help you figure out how to do things. The installation tests in
 the `t/` and `xt/` directories might also be useful to you.
+
+### A Note on Paper Sizes
+
+Per PDF specifications, the default paper (media) size set in PDF::Builder
+is 'US Letter' (8.5in x 11in, 216mm x 279mm). If you're in the civilized world,
+and don't measure things in "bananas",
+you may wish to specify 'A4' instead, in the `\$pdf->mediabox('A4');` call.
+Note that A4 is narrower and taller than Letter. If you want to ensure that
+your output will be printable around the world, consider using the _universal_
+paper size: `\$pdf->mediabox('universal');`.
+This will result in some wasted
+space at the top of a printed A4 page, or some wasted right margin on a printed
+Letter page, but it's better than having content cut off! It may also be
+satisfactory to leave sufficient _margins_ around document content on standard
+US Letter _or_ A4 media, with the following **minimum** margins (allowing
+3mm/.125" for paper handling, plus extra for media size differences):
+
+`bottom: 3mm = .125" = 9pt`  (bottom same for all media)
+
+`left:   3mm = .125" = 9pt`  (left same for all media)
+
+
+`A4 top:     21mm = .83" = 60pt` (A4 taller than Letter)
+
+`Letter top: 3mm = .125" = 9pt`
+
+`Letter right:  9mm = .375" = 27pt` (Letter wider than A4)
+
+`A4 right:      3mm = .125" = 9pt`
+
+Please see the discussion on `mediabox()` and other "box" calls, about how
+much of a page can actually be _printed_ on, allowing for pinch rollers and
+other paper transport mechanisms. The above suggested margins assume, in
+addition to Letter paper being .25" wider and .7" shorter than A4, that 1/8"
+(9pt, 3mm) of paper is unprintable around the edges; your printer may vary.
 END_OF_CONTENT
 
-restore_props($text, $grfx);
+restore_props($text,$grfx);
+# page 5
 ($rc, $next_y, $unused) =
     $text->column($page, $text, $grfx, 'md1', $content, 
 	          'rect'=>[50,750, 500,700], 'outline'=>$magenta, 
 		  'para'=>[ 0, 5 ] );
+# pages 6-8
 while ($rc) { 
-    # new page
+    # new page. uses fixed column template, no headers/footers/page numbers
     $page = $pdf->page();
-    $text = $page->text();
     $grfx = $page->gfx();
+    $text = $page->text();
+    footer(++$page_num, $pdf, $text);
 
+#print Dumper($unused) if $page_num == 7;
     ($rc, $next_y, $unused) =
         $text->column($page, $text, $grfx, 'pre', $unused, 
 		      'rect'=>[50,750, 500,700], 'outline'=>$magenta, 
 		      'para'=>[ 0, 5 ] );
 }
 
-# a variety of lists over multiple pages
-print "======================================================= pg 9\n";
-print "---- A variety of lists\n";
-$page = $pdf->page();
-$text = $page->text();
-$grfx = $page->gfx();
-
-$content = <<"END_OF_CONTENT";
-<h2>Unordered (bulleted) lists with various markers</h2>
-<ul> <!-- default disc -->
-  <li>Unordered 1A, disc and here is a bunch more text to try to cause a spill to a second line. Looks like we need a bit more filler here.</li>
-  <li>Unordered 1B
-  <ul> <!-- default circle -->
-    <li>Unordered 2A, circle</li>
-    <li>Unordered 2B and here is a bunch more text to try to cause a spill to a second line. Looks like we need a bit more filler here.
-    <ul> <!-- default (filled) square -->
-      <li>Unordered 3A, square</li>
-      <li>Unordered 3B
-      <ul style="list-style-type: box"> <!-- box (open square) -->
-        <li>Unordered 4A, box. A &ldquo;box&rdquo; marker is non-standard &mdash; it is an empty square marker. A bit more filler here. How about a <i>lot</i> more, driving it to three lines in all? Oh yeah, that's the ticket!</li>
-        <li>Unordered 4B
-        <ul style="list-style-type: disc"> <!-- and back to disc -->
-          <li>Unordered 5A, disc</li>
-          <li>Unordered 5B</li>
-	</ul>
-	<ul> <!-- default (filled) square) -->
-          <li>Unordered 6A, square</li>
-          <li>Unordered 6B</li>
-	</ul></li>
-      </ul></li>
-    </ul></li>
-  </ul></li>
-</ul>
-
-<h2>Ordered (numbered) lists with various markers</h2>
-<ol> <!-- default decimal -->
-  <li>Ordered 1A, decimal 1., 2.</li>
-  <li>Ordered 1B
-  <ol style="list-style-type: upper-roman"> <!-- I, II, III, IV -->
-    <li>Ordered 2A, upper-roman I., II.</li>
-    <li>Ordered 2B
-    <ol style="list-style-type: upper-alpha"> <!-- A, B, C, D -->
-      <li>Ordered 3A, upper-alpha A., B.</li>
-      <li>Ordered 3B
-      <ol style="list-style-type: lower-roman"> <!-- i, ii, iii, iv -->
-        <li>Ordered 4A, lower-roman i., ii.</li>
-        <li>Ordered 4B
-        <ol style="list-style-type: lower-alpha"> <!-- a, b, c, d -->
-          <li>Ordered 5A lower-alpha a., b.</li>
-          <li>Ordered 5B</li>
-	</ol>
-        <ol> <!-- default decimal -->
-          <li>Ordered 6A, decimal 1., 2.</li>
-          <li>Ordered 6B</li>
-	</ol></li>
-      </ol></li>
-    </ol></li>
-  </ol></li>
-</ol>
-END_OF_CONTENT
-
-restore_props($text, $grfx);
-($rc, $next_y, $unused) =
-    $text->column($page, $text, $grfx, 'html', $content, 
-	          'rect'=>[50,750, 500,700], 'outline'=>$magenta, 
-		  'para'=>[ 0, 0 ] );
-if ($rc) {
-    print STDERR "list example overflowed column!\n";
-}
-
-print "======================================================= pg 10\n";
-print "---- More list examples\n";
-$page = $pdf->page();
-$text = $page->text();
-$grfx = $page->gfx();
-
-$content = <<"END_OF_CONTENT";
-<h2>Mixture of ordered and unordered with default markers</h2>
-<ol> <!-- default decimal -->
-  <li>Ordered 1A, decimal 1., 2.</li>
-  <li>Ordered 1B
-  <ul> <!-- default circle -->
-    <li>Unordered 2A, circle</li>
-    <li>Unordered 2B
-    <ol> <!-- default decimal -->
-      <li>Ordered 3A, decimal 1., 2.</li>
-      <li>Ordered 3B
-      <ul> <!-- default (filled) square -->
-        <li>Unordered 4A, square</li>
-        <li>Unordered 4B
-        <ol> <!-- default decimal -->
-          <li>Ordered 5A, decimal 1., 2.</li>
-          <li>Ordered 5B</li>
-	</ol>
-        <ul> <!-- default (filled) square -->
-          <li>Unordered 6A, square</li>
-          <li>Unordered 6B</li>
-	</ul></li>
-      </ul></li>
-    </ol></li>
-  </ul></li>
-</ol>
-
-<!-- TBD position inside/outside
-<h2>list-style-position inside and outside, with multiline li's</h2>
--->
-END_OF_CONTENT
-
-restore_props($text, $grfx);
-($rc, $next_y, $unused) =
-    $text->column($page, $text, $grfx, 'html', $content, 
-	          'rect'=>[50,750, 500,450], 'outline'=>$magenta, 
-		  'para'=>[ 0, 0 ] );
-if ($rc) {
-    print STDERR "list example overflowed column!\n";
-}
-
-# try nesting in Markdown
-$content = <<"END_OF_CONTENT";
-## Try nested Markdown entries (manually indent items)
-
-1. This is a numbered list unnested.
-2. This is another item in the numbered list.
-   - This is a first nested level bulleted list.
-     - This is a further nested bulleted list.
-     - And a second item.
-   - Back to first nested level bulleted list
-3. One last numbered list item
-END_OF_CONTENT
-
-restore_props($text, $grfx);
-($rc, $next_y, $unused) =
-    $text->column($page, $text, $grfx, 'md1', $content, 
-	          'rect'=>[50,250, 500,200], 'outline'=>$magenta, 
-		  'para'=>[ 0, 0 ] );
-if ($rc) {
-    print STDERR "list example overflowed column!\n";
-}
-
-# Counting down (reversed) ordered lists
-print "======================================================= pg 11\n";
-print "---- Count down list examples\n";
-$page = $pdf->page();
-$text = $page->text();
-$grfx = $page->gfx();
-
-$content = <<"END_OF_CONTENT";
-<h2>Test reversed ordered lists</h2>
-<ol reversed="1" start="10">
-  <li>ten</li>
-  <li>nine</li>
-  <li>eight</li>
-  <li>seven</li>
-  <li>six</li>
-  <li>five
-  <ol>
-    <li>holding</li>
-    <li>resume countdown</li>
-  </ol></li>
-  <li>four</li>
-  <li>three</li>
-  <li>two</li>
-  <li>one</li>
-</ol>
-<h2>Reversed ordered list run past 1</h2>
-<ol reversed="1" start="3">
-  <li>three</li>
-  <li>two</li>
-  <li>one</li>
-  <li>zero... blast off!</li>
-  <li>minus one... the clock is running</li>
-</ol>
-END_OF_CONTENT
-
-restore_props($text, $grfx);
-($rc, $next_y, $unused) =
-    $text->column($page, $text, $grfx, 'html', $content, 
-	          'rect'=>[50,750, 500,450], 'outline'=>$magenta, 
-		  'para'=>[ 0, 0 ] );
-if ($rc) {
-    print STDERR "list example overflowed column!\n";
-}
-
+# for various lists, see Column_lists.pl
 
 # block quotes and font extent changes
-print "======================================================= pg 12\n";
+print "======================================================= pg 11\n";
 print "---- Block quotes\n";
 $page = $pdf->page();
-$text = $page->text();
 $grfx = $page->gfx();
+$text = $page->text();
+footer(++$page_num, $pdf, $text);
 
 $content = <<"END_OF_CONTENT";
 <h2>Block Quote (left and right margins)</h2>
@@ -916,65 +849,18 @@ END_OF_CONTENT
 restore_props($text, $grfx);
 ($rc, $next_y, $unused) =
     $text->column($page, $text, $grfx, 'html', $content, 
-	          'rect'=>[50,400, 500,350], 'outline'=>$magenta, 
+	          'rect'=>[50,425, 500,380], 'outline'=>$magenta, 
 		  'para'=>[ 0, 0 ] );
 if ($rc) { 
     print STDERR "Font size changes example overflowed column!\n";
 }
 
 # setting your own CSS for Markdown or none
-print "======================================================= pg 13\n";
+print "======================================================= pg 12\n";
 $page = $pdf->page();
-$text = $page->text();
 $grfx = $page->gfx();
-
-print "---- default CSS for Markdown\n";
-$content = <<"END_OF_CONTENT";
-Ordered list with no margin-top/bottom (extra space between elements)
-
-1. Numbered item 1.
-2. Numbered item 2.
-3. Numbered item 3.
-
-## And a subheading to make green
-END_OF_CONTENT
-
-restore_props($text, $grfx);
-($rc, $next_y, $unused) =
-    $text->column($page, $text, $grfx, 'md1', $content, 
-	          'rect'=>[50,750, 500,100], 'outline'=>$magenta, 
-		  'para'=>[ 0, 0 ] );
-if ($rc) { 
-    print STDERR "Markdown CSS example overflowed column!\n";
-}
-
-print "---- set CSS for Markdown\n";
-$content = <<"END_OF_CONTENT";
-Ordered list with no margin-top/bottom (no space between elements) and new marker format
-
-1. Numbered item 1.
-2. Numbered item 2.
-3. Numbered item 3.
-
-## And a subheading to make green
-END_OF_CONTENT
-
-restore_props($text, $grfx);
-($rc, $next_y, $unused) =
-    $text->column($page, $text, $grfx, 'md1', $content, 
-	          'rect'=>[50,650, 500,100], 'outline'=>$magenta, 
-		  'para'=>[ 0, 0 ],
-	          'style'=>"
-        ol { _marker-before: '(' ; _marker-after: ')' ; }
-        li { margin-top: 0; margin-bottom: 0 } 
-        h2 { color: green; }
-       ", 
-        # marker-before/after could be in ol, too 
-	# note that comments not supported in CSS
-	         );
-if ($rc) { 
-    print STDERR "Markdown CSS example overflowed column!\n";
-}
+$text = $page->text();
+footer(++$page_num, $pdf, $text);
 
 print "---- horizontal rules Markdown\n";
 $content = <<"END_OF_CONTENT";
@@ -996,30 +882,31 @@ END_OF_CONTENT
 restore_props($text, $grfx);
 ($rc, $next_y, $unused) =
     $text->column($page, $text, $grfx, 'md1', $content, 
-	          'rect'=>[50,525, 500,125], 'outline'=>$magenta, 
+	          'rect'=>[50,750, 500,125], 'outline'=>$magenta, 
 		  'para'=>[ 0, 0 ],
 	         );
 if ($rc) { 
     print STDERR "Markdown horizontal rule example overflowed column!\n";
 }
 
+# note some tags capitalized, and some attributes capitalized
 print "---- horizontal rules HTML\n";
 $content = <<"END_OF_CONTENT";
 <p>HTML horizontal rules, with CSS</p>
-<hr>
+<hR>
 <p>Between two rules, above is default settings</p>
 <hr style="height: 5; color: blue">
 <p>Between two rules, above is very thick and blue</p>
 <hr style="width: 200" />
-<p>Above rule is only 200pt long</p>
-<hr size="17" color="orange" width="300">
+<P>Above rule is only 200pt long</p>
+<HR size="17" Color="orange" WIDTH="300">
 <p>Above rule is <em>very</em> thick orange and 300pt long</p>
 END_OF_CONTENT
 
 restore_props($text, $grfx);
 ($rc, $next_y, $unused) =
     $text->column($page, $text, $grfx, 'html', $content, 
-	          'rect'=>[50,400, 500,185], 'outline'=>$magenta, 
+	          'rect'=>[50,585, 500,185], 'outline'=>$magenta, 
 		  'para'=>[ 0, 0 ],
 	         );
 if ($rc) { 
@@ -1038,14 +925,129 @@ END_OF_CONTENT
 restore_props($text, $grfx);
 ($rc, $next_y, $unused) =
     $text->column($page, $text, $grfx, 'md1', $content, 
-	          'rect'=>[50,200, 500,100], 'outline'=>$magenta, 
+	          'rect'=>[50,375, 500,100], 'outline'=>$magenta, 
 		  'para'=>[ 0, 10 ],
 	         );
 if ($rc) { 
     print STDERR "PDF links example overflowed column!\n";
 }
 
-# might have to go to a column2.pl!
+# --------------
+# some bogus tags and CSS properties
+# expect one message about invalid 'glotz' tag. notice that HTML::TreeBuilder
+#   does NOT insert an extra </glotz> tag into the stream, as one already found
+# expect 'snork' CSS to be ignored
+#
+print "---- Bogus HTML tags and CSS property names\n";
+$content = <<"END_OF_CONTENT";
+<p>
+<glotz>This is within a 'glotz' tag</glotz>. 
+This is <glotz>within another.</glotz>
+</p>
+
+<p style="snork: 1em;">This paragraph has CSS 'snork' property.</p>
+END_OF_CONTENT
+
+restore_props($text, $grfx);
+($rc, $next_y, $unused) =
+    $text->column($page, $text, $grfx, 'md1', $content, 
+	          'rect'=>[50,260, 500,60], 'outline'=>$magenta, 
+		  'para'=>[ 0, 10 ],
+	         );
+if ($rc) { 
+    print STDERR "Invalid tags and CSS example overflowed column!\n";
+}
+ 
+# ------ some <_move> and text-align usage
+#
+print "---- <_move> and text-align usage\n";
+$content = <<"END_OF_CONTENT";
+<p>
+<span style="text-align: left;">text-align: left</span>
+</p>
+END_OF_CONTENT
+
+restore_props($text, $grfx);
+($rc, $next_y, $unused) =
+    $text->column($page, $text, $grfx, 'html', $content, 
+	          'rect'=>[100,187, 400,13], 'outline'=>$magenta, 
+		  'para'=>[ 0, 0 ],
+	         );
+if ($rc) { 
+    print STDERR "1. <_move> and text-align example overflowed column!\n";
+}
+ 
+$content = <<"END_OF_CONTENT";
+<p>
+<_move x="50%"><span style="text-align: center;">text-align: center</span>
+</p>
+END_OF_CONTENT
+
+restore_props($text, $grfx);
+($rc, $next_y, $unused) =
+    $text->column($page, $text, $grfx, 'html', $content, 
+	          'rect'=>[100,174, 400,13], 'outline'=>$magenta, 
+		  'para'=>[ 0, 0 ],
+	         );
+if ($rc) { 
+    print STDERR "2. <_move> and text-align example overflowed column!\n";
+}
+ 
+$content = <<"END_OF_CONTENT";
+<p>
+<_move x="100%"><span style="text-align: right;">text-align: right</span>
+</p>
+END_OF_CONTENT
+
+restore_props($text, $grfx);
+($rc, $next_y, $unused) =
+    $text->column($page, $text, $grfx, 'html', $content, 
+	          'rect'=>[100,161, 400,13], 'outline'=>$magenta, 
+		  'para'=>[ 0, 0 ],
+	         );
+if ($rc) { 
+    print STDERR "3. <_move> and text-align example overflowed column!\n";
+print "rc=$rc, leftover text =\n";
+print Dumper(@$unused);
+}
+ 
+$content = <<"END_OF_CONTENT";
+<p>
+<_move x="50%"><span style="text-align: center;">1.text at center</span>
+<_move x="0%"><span style="text-align: left;">2.explicit LJ at 0%</span>
+<_move x="100%"><span style="text-align: right;">3.RJ text at 100%</span>
+</p>
+END_OF_CONTENT
+
+restore_props($text, $grfx);
+($rc, $next_y, $unused) =
+    $text->column($page, $text, $grfx, 'html', $content, 
+	          'rect'=>[100,144, 400,13], 'outline'=>$magenta, 
+		  'para'=>[ 0, 0 ],
+	         );
+if ($rc) { 
+    print STDERR "4. <_move> and text-align example overflowed column!\n";
+}
+ 
+$content = <<"END_OF_CONTENT";
+<p>
+<_move x="50%" dx="72">1.Center+72pt LJ text.
+<_move x="50%" dx="-72"><span style="text-align: center;">2.Center-72pt CJ text.</span>
+</p>
+END_OF_CONTENT
+
+restore_props($text, $grfx);
+($rc, $next_y, $unused) =
+    $text->column($page, $text, $grfx, 'html', $content, 
+	          'rect'=>[100,131, 400,13], 'outline'=>$magenta, 
+		  'para'=>[ 0, 0 ],
+	         );
+if ($rc) { 
+    print STDERR "5. <_move> and text-align example overflowed column!\n";
+}
+ 
+# Column_layouts.pl TBD
+# TBD figure out a good way to fall back for unavailable fonts
 # demonstrate balanced columns two long columns and one short, first pass
 #   fill blindly, overflowing to column 2 then 3, then by trial-and-error
 #   shorten long two columns until short one just fills (show initial and
@@ -1066,6 +1068,22 @@ if ($rc) {
 # end of program
 $pdf->saveas($name);
 # -----------------------
+ 
+sub footer {
+    my ($page_num, $pdf, $text) = @_;
+    # columns are generally 50 - 500 so center page number there
+    # save current font and size
+    my ($cur_font, $cur_fs) = $text->font();
+
+    $text->font($pdf->get_font('face'=>'sans-serif', 'italic'=>0, 'bold'=>0), 10);
+    $text->translate((500-50)*0.5+50, 10);
+    $text->text("- $page_num -", 'align'=>'center');
+
+    # restore font conditions on entry (if they were ever set)
+    $text->font($cur_font, $cur_fs) if $cur_fs > 0;
+    return;
+}
+# -----------------------
 
 sub multicol {
     my ($page, $text, $grfx, $markup, $content, $rect, $outline, $fs) = @_;
