@@ -5,8 +5,8 @@ use base 'PDF::Builder::Resource::ColorSpace::Indexed';
 use strict;
 use warnings;
 
-our $VERSION = '3.024'; # VERSION
-our $LAST_UPDATE = '3.024'; # manually update whenever code is changed
+our $VERSION = '3.027'; # VERSION
+our $LAST_UPDATE = '3.027'; # manually update whenever code is changed
 
 use PDF::Builder::Basic::PDF::Utils;
 use PDF::Builder::Util;
@@ -16,11 +16,15 @@ use Scalar::Util qw(weaken);
 
 PDF::Builder::Resource::ColorSpace::Indexed::ACTFile - Adobe Color Table support
 
+Inherits from L<PDF::Builder::Resource::ColorSpace::Indexed>
+
 =head1 METHODS
 
-=over
+=head2 new
 
-=item $cs = PDF::Builder::Resource::ColorSpace::Indexed::ACTFile->new($pdf, $actfile)
+    $cs = PDF::Builder::Resource::ColorSpace::Indexed::ACTFile->new($pdf, $actfile)
+
+=over
 
 Returns a new colorspace object created from an adobe color table file (ACT/8BCT).
 See
@@ -29,6 +33,8 @@ File Formats Specification Version 6.0 Release 2,
 November 2000
 for details.
 
+=back
+
 =cut
 
 sub new {
@@ -63,8 +69,4 @@ sub new {
     return $self;
 }
 
-=back
-
-=cut
-
 1;
